summaryrefslogtreecommitdiffstats
path: root/bibletime/bibletime_slots.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'bibletime/bibletime_slots.cpp')
-rw-r--r--bibletime/bibletime_slots.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/bibletime/bibletime_slots.cpp b/bibletime/bibletime_slots.cpp
index 191bc2c..074536f 100644
--- a/bibletime/bibletime_slots.cpp
+++ b/bibletime/bibletime_slots.cpp
@@ -66,10 +66,10 @@ using namespace Profile;
/* An action which stores a user defined pointer to a widget.
* @author Joachim Ansorg
*/
-class KUserDataAction : public KToggleAction {
+class KUserDataAction : public TDEToggleAction {
public:
- KUserDataAction( TQString caption, const KShortcut& shortcut, const TQObject* receiver, const char* slot, KActionCollection* actionCollection)
-: KToggleAction(caption, shortcut, receiver, slot, actionCollection), m_userData(0) { /* no impl */
+ KUserDataAction( TQString caption, const TDEShortcut& shortcut, const TQObject* receiver, const char* slot, TDEActionCollection* actionCollection)
+: TDEToggleAction(caption, shortcut, receiver, slot, actionCollection), m_userData(0) { /* no impl */
};
void setUserData(TQWidget* const data) {
@@ -171,15 +171,15 @@ void BibleTime::slotWindowMenuAboutToShow() {
m_windowCloseAll_action->setEnabled( true );
}
- TQPtrList<KAction>::iterator end = m_windowOpenWindowsList.end();
- for (TQPtrList<KAction>::iterator it = m_windowOpenWindowsList.begin(); it != end; ++it ) {
+ TQPtrList<TDEAction>::iterator end = m_windowOpenWindowsList.end();
+ for (TQPtrList<TDEAction>::iterator it = m_windowOpenWindowsList.begin(); it != end; ++it ) {
(*it)->unplugAll();
}
m_windowOpenWindowsList.setAutoDelete(true);
m_windowOpenWindowsList.clear();
if (!m_windowActionCollection) {
- m_windowActionCollection = new KActionCollection(this);
+ m_windowActionCollection = new TDEActionCollection(this);
}
TQWidgetList windows = m_mdi->windowList();
@@ -188,7 +188,7 @@ void BibleTime::slotWindowMenuAboutToShow() {
TQWidget* w = windows.at(i);
Q_ASSERT(w);
- KUserDataAction* action = new KUserDataAction(w->caption(), KShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotWindowMenuActivated()), m_windowActionCollection);
+ KUserDataAction* action = new KUserDataAction(w->caption(), TDEShortcut(), TQT_TQOBJECT(this), TQT_SLOT(slotWindowMenuActivated()), m_windowActionCollection);
Q_ASSERT(action);
action->setUserData(w);
@@ -199,7 +199,7 @@ void BibleTime::slotWindowMenuAboutToShow() {
}
/** This slot is connected with the windowAutoTile_action object */
-void BibleTime::slotUpdateWindowArrangementActions( KAction* clickedAction ) {
+void BibleTime::slotUpdateWindowArrangementActions( TDEAction* clickedAction ) {
/* If a toggle action was clicked we see if it checked ot unchecked and
* enable/disable the simple cascade and tile options accordingly
*/
@@ -396,7 +396,7 @@ void BibleTime::openOnlineHelp_Howto() {
void BibleTime::saveProfile(int ID) {
m_mdi->setUpdatesEnabled(false);
- KPopupMenu* popup = m_windowSaveProfile_action->popupMenu();
+ TDEPopupMenu* popup = m_windowSaveProfile_action->popupMenu();
const TQString profileName = popup->text(ID).remove("&");
CProfile* p = m_profileMgr.profile( profileName );
Q_ASSERT(p);
@@ -435,8 +435,8 @@ void BibleTime::saveProfile(CProfile* profile) {
}
void BibleTime::loadProfile(int ID) {
- KPopupMenu* popup = m_windowLoadProfile_action->popupMenu();
- //HACK: workaround the inserted & char by KPopupMenu
+ TDEPopupMenu* popup = m_windowLoadProfile_action->popupMenu();
+ //HACK: workaround the inserted & char by TDEPopupMenu
const TQString profileName = popup->text(ID).remove("&");
CProfile* p = m_profileMgr.profile( profileName );
// tqWarning("requesting popup: %s", popup->text(ID).latin1());
@@ -505,8 +505,8 @@ void BibleTime::loadProfile(CProfile* p) {
}
void BibleTime::deleteProfile(int ID) {
- KPopupMenu* popup = m_windowDeleteProfile_action->popupMenu();
- //HACK: work around the inserted & char by KPopupMenu
+ TDEPopupMenu* popup = m_windowDeleteProfile_action->popupMenu();
+ //HACK: work around the inserted & char by TDEPopupMenu
const TQString profileName = popup->text(ID).remove("&");
CProfile* p = m_profileMgr.profile( profileName );
Q_ASSERT(p);
@@ -536,13 +536,13 @@ void BibleTime::saveToNewProfile() {
/** Slot to refresh the save profile and load profile menus. */
void BibleTime::refreshProfileMenus() {
- KPopupMenu* savePopup = m_windowSaveProfile_action->popupMenu();
+ TDEPopupMenu* savePopup = m_windowSaveProfile_action->popupMenu();
savePopup->clear();
- KPopupMenu* loadPopup = m_windowLoadProfile_action->popupMenu();
+ TDEPopupMenu* loadPopup = m_windowLoadProfile_action->popupMenu();
loadPopup->clear();
- KPopupMenu* deletePopup = m_windowDeleteProfile_action->popupMenu();
+ TDEPopupMenu* deletePopup = m_windowDeleteProfile_action->popupMenu();
deletePopup->clear();
//refresh the load, save and delete profile menus